aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/grpcpp/impl/codegen/rpc_service_method.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/grpcpp/impl/codegen/rpc_service_method.h')
-rw-r--r--include/grpcpp/impl/codegen/rpc_service_method.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/include/grpcpp/impl/codegen/rpc_service_method.h b/include/grpcpp/impl/codegen/rpc_service_method.h
index 1890e4254d..f465c5fc2f 100644
--- a/include/grpcpp/impl/codegen/rpc_service_method.h
+++ b/include/grpcpp/impl/codegen/rpc_service_method.h
@@ -46,21 +46,22 @@ class MethodHandler {
/// \param context : the ServerContext structure for this server call
/// \param req : the request payload, if appropriate for this RPC
/// \param req_status : the request status after any interceptors have run
/// \param renew : used only by the callback API. It is a function
/// called by the RPC Controller to request another RPC
HandlerParameter(Call* c, ServerContext* context, void* req,
- Status req_status, std::function<void()> renew)
+ Status req_status, std::function<void()> requester)
: call(c),
server_context(context),
request(req),
status(req_status),
- renewer(std::move(renew)) {}
+ call_requester(std::move(requester)) {}
~HandlerParameter() {}
Call* call;
ServerContext* server_context;
void* request;
Status status;
- std::function<void()> renewer;
+ std::function<void()> call_requester;
};
virtual void RunHandler(const HandlerParameter& param) = 0;
@@ -46,21 +46,22 @@ class MethodHandler {
/// \param req : the request payload, if appropriate for this RPC
/// \param req_status : the request status after any interceptors have run
- /// \param renew : used only by the callback API. It is a function
- /// called by the RPC Controller to request another RPC
+ /// \param rpc_requester : used only by the callback API. It is a function
+ /// called by the RPC Controller to request another RPC (and also
+ /// to set up the state required to make that request possible)
HandlerParameter(Call* c, ServerContext* context, void* req,